package com.ynet.life.sujrb.file.parser;

import com.ynet.life.base.LifeStandard;
import com.ynet.life.base.Trace;
import com.ynet.life.exception.TranFailException;
import com.ynet.life.file.LifeFile;
import com.ynet.life.format.LifeFormat;
import com.ynet.life.sujrb.file.BatchFileSummary;
import com.ynet.life.sujrb.file.BatchPaySummary;
import com.ynet.life.sujrb.file.FileConstants;
import java.math.BigDecimal;
import java.util.HashMap;
import java.util.Map;

/* loaded from: com_ynet_life_sujrb_file_parser.jar:com/ynet/life/sujrb/file/parser/BatchPayCSVFileParser.class */
public class BatchPayCSVFileParser implements BatchFileParserInterface {
    private static final String COMMA = ",";

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public BatchFileSummary parseFromFile(String filePathName) throws TranFailException {
        int max;
        BatchPaySummary result = new BatchPaySummary();
        String[] lineArray = LifeFile.readTextFileToString(filePathName).split(LifeFile.LINE_SEPARATOR);
        int size = lineArray.length;
        if (size < 2) {
            Trace.logWarning("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏");
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
        try {
            Map totalMap = getTotalRecordMap(lineArray[0]);
            int recordNumberInput = Integer.parseInt((String) totalMap.get("totalNumber"));
            BigDecimal bigDecimal = new BigDecimal(LifeFormat.unFormatCurrency((String) totalMap.get("totalAmount")));
            for (int i = 1; i < size; i++) {
                String lineContent = lineArray[i];
                if (lineContent.trim().length() > 0) {
                    result.addRecord(getRecordMap(lineContent));
                }
            }
            if (result.getRecordNumber() != recordNumberInput || bigDecimal.compareTo(result.getTotalAmount()) != 0) {
                Trace.logWarning("LifeFile", "提交文件中总笔数或总金额和明细不符");
                throw FileConstants.EXCEPTION_VALIDATE_FAIL;
            }
            try {
                max = Integer.parseInt(LifeStandard.getSystemParam("CB_BATCH_TRANSFER_MAX_NUM"));
            } catch (NumberFormatException unused) {
                max = 500;
            }
            if (recordNumberInput > max) {
                Trace.logWarning("LifeAction", "EBCB0505::提交文件总笔数超过要求的值");
                throw new TranFailException("EBCB0505", "提交文件总笔数超过要求的值", false);
            }
            return result;
        } catch (Exception e) {
            Trace.logError("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏", e);
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
    }

    private Map getTotalRecordMap(String record) throws TranFailException {
        Map result = new HashMap();
        String[] elementArray = record.split(COMMA, 2);
        if (elementArray.length < 2) {
            Trace.logWarning("LifeFile", "文件解析失败，请检查提交文件是否正确，并确保文件未被损坏");
            throw FileConstants.EXCEPTION_PARSE_FAIL;
        }
        String recordNumber = elementArray[0].trim();
        String totalAmount = elementArray[1].trim();
        result.put("totalNumber", recordNumber);
        result.put("totalAmount", totalAmount);
        return result;
    }

    private Map getRecordMap(String record) throws TranFailException {
        Map result = new HashMap();
        String[] elementArray = record.split(COMMA, 14);
        String payAccount = elementArray[0].trim();
        String payAccountName = elementArray[1].trim();
        String recAccount = elementArray[2].trim();
        String recAccountName = elementArray[3].trim();
        String recAccountOpenBank = elementArray[4].trim();
        String unionBankNo = elementArray[5].trim();
        String recBankType = elementArray[6].trim();
        String currencyType = elementArray[7].trim();
        String payAmount = elementArray[8].trim();
        String rmtType = elementArray[9].trim();
        String transferTowardType = elementArray[10].trim();
        String tranChannel = elementArray[11].trim();
        String payUse = elementArray[12].trim();
        String payRem = elementArray[13].trim();
        result.put("payAccount", payAccount);
        result.put("payAccountName", payAccountName);
        result.put("recAccount", recAccount);
        result.put("recAccountName", recAccountName);
        result.put("recAccountOpenBank", recAccountOpenBank);
        result.put("unionBankNo", unionBankNo);
        result.put("recBankType", recBankType);
        result.put("currencyType", currencyType);
        result.put("payAmount", LifeFormat.unFormatCurrency(LifeFormat.formatCurrency(LifeFormat.unFormatCurrency(payAmount))));
        result.put("rmtType", rmtType);
        result.put("transferTowardType", transferTowardType);
        result.put("tranChannel", tranChannel);
        result.put("payUse", payUse);
        result.put("payRem", payRem);
        return result;
    }

    @Override // com.ynet.life.sujrb.file.parser.BatchFileParserInterface
    public void writeToFile(BatchFileSummary salary, String filePathName, String encoding) throws TranFailException {
    }
}
